@@ -1,13 +1,13 @@
 import unittest
 
-import mlops_models as mlops
+from mlops_models.constant import ConstantPredictionModel
 
 
 class TestConstantPredictionModel(unittest.TestCase):
 
 	def test_constant_matches_initilized_value(self):
 
-		model = mlops.ConstantPredictionModel(0)
+		model = ConstantPredictionModel(0)
 		self.assertEqual(model.predict(None), 0)
 
 		# Test diferent data types
@@ -17,14 +17,14 @@ class TestConstantPredictionModel(unittest.TestCase):
 		self.assertEqual(model.predict(["a"]), 0)
 
 
-		model = mlops.ConstantPredictionModel(1)
+		model = ConstantPredictionModel(1)
 		self.assertEqual(model.predict(None), 1)
 
 
 	def test_default_init_value(self):
 
-		model = mlops.ConstantPredictionModel()
+		model = ConstantPredictionModel()
 		self.assertEqual(model.predict(None), 0)
 
-		model = mlops.ConstantPredictionModel()
+		model = ConstantPredictionModel()
 		self.assertNotEqual(model.predict(None), 1)
